@@ -145,7 +145,12 @@ static const bool ExtraDebug = false;
 // the memory footprint.)
 struct OneState {
   uint32_t matchcond;   // conditions to match right now.
-  uint32_t action[1];
+  // Workaround for compiler warning:
+  //   "flexible array members are a C99 feature [-Wc99-extensions]"
+  // declaring action[1] will remove above warning but it will not pass
+  //   UBSAN check since compiler will complain about array out of bounds.
+  // uint32_t action[];
+  uint32_t action[256];
 };
 
 // The uint32_t conditions in the action are a combination of
@@ -245,7 +250,11 @@ bool Prog::SearchOnePass(const StringPiece& text,
     kind = kFullMatch;
 
   uint8_t* nodes = onepass_nodes_.data();
-  int statesize = sizeof(OneState) + bytemap_range()*sizeof(uint32_t);
+  // In the original definition of OneState (with action[]), size of
+  //   OneState was same as size of unit32_t (action[] has size 0 but fixes
+  //   action[size] array right next to matchcomd in memory.
+  int statesize = sizeof(uint32_t) + bytemap_range()*sizeof(uint32_t);
+  // int statesize = sizeof(OneState) + bytemap_range()*sizeof(uint32_t);
   // start() is always mapped to the zeroth OneState.
   OneState* state = IndexToNode(nodes, statesize, 0);
   uint8_t* bytemap = bytemap_;
@@ -394,7 +403,8 @@ bool Prog::IsOnePass() {
   // Limit max node count to 65000 as a conservative estimate to
   // avoid overflowing 16-bit node index in encoding.
   int maxnodes = 2 + inst_count(kInstByteRange);
-  int statesize = sizeof(OneState) + bytemap_range()*sizeof(uint32_t);
+  int statesize = sizeof(uint32_t) + bytemap_range()*sizeof(uint32_t);
+  // int statesize = sizeof(OneState) + bytemap_range()*sizeof(uint32_t);
   if (maxnodes >= 65000 || dfa_mem_ / 4 / statesize < maxnodes)
     return false;
 
